==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ig.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ig extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "JPY", "\u00a5" },
            { "NGN", "\u20a6" },
            { "USD", "$" },
            { "aed", "Ego Dirham obodo United Arab Emirates" },
            { "afn", "Ego Afghani Obodo Afghanistan" },
            { "all", "Ego Lek Obodo Albania" },
            { "amd", "Ego Dram obodo Armenia" },
            { "ang", "Ego Antillean Guilder obodo Netherlands" },
            { "aoa", "Ego Kwanza obodo Angola" },
            { "ars", "Ego Peso obodo Argentina" },
            { "aud", "Ego Dollar obodo Australia" },
            { "awg", "Ego Florin obodo Aruba" },
            { "azn", "Ego Manat obodo Azerbaijan" },
            { "bam", "Akara mgbanwe ego obodo Bosnia-Herzegovina" },
            { "bbd", "Ego Dollar obodo Barbados" },
            { "bdt", "Ego Taka obodo Bangladesh" },
            { "bgn", "Ego Lev mba Bulgaria" },
            { "bhd", "Ego Dinar Obodo Bahrain" },
            { "bif", "Ego Franc obodo Burundi" },
            { "bmd", "Dollar Bermuda" },
            { "bnd", "Ego Dollar obodo Brunei" },
            { "bob", "Ego Boliviano obodo Bolivia" },
            { "brl", "Real Brazil" },
            { "bsd", "Ego Dollar Obodo Bahamas" },
            { "btn", "Ego Ngultrum obodo Bhutan" },
            { "bwp", "Ego Pula obodo Bostwana" },
            { "byn", "Ego Ruble mba Belarus" },
            { "bzd", "Dollar Belize" },
            { "cad", "Dollar Canada" },
            { "cdf", "Ego Franc obodo Congo" },
            { "chf", "Ego Franc mba Switzerland" },
            { "clp", "Ego Peso obodo Chile" },
            { "cnh", "Ego Yuan Obodo China (nd\u1ecb bi na mmiri)" },
            { "cny", "Yuan China" },
            { "cop", "Ego Peso obodo Columbia" },
            { "crc", "Ego Col\u00f3n obodo Costa Rica" },
            { "cuc", "Ego Peso e nwere ike \u1ecbgbanwe nke obodo Cuba" },
            { "cup", "Ego Peso obodo Cuba" },
            { "cve", "Escudo Caboverdiano" },
            { "czk", "Ego Koruna obodo Czech" },
            { "djf", "Ego Franc obodo Djibouti" },
            { "dkk", "Ego Krone Obodo Denmark" },
            { "dop", "Ego Peso Obodo Dominica" },
            { "dzd", "Ego Dinar Obodo Algeria" },
            { "egp", "Ego Pound obodo Egypt" },
            { "ern", "Ego Nakfa obodo Eritrea" },
            { "etb", "Ego Birr obodo Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Ego Dollar obodo Fiji" },
            { "fkp", "Ego Pound obodo Falkland Islands" },
            { "gbp", "Pound British" },
            { "gel", "Ego Lari Obodo Georgia" },
            { "ghs", "Ego Cedi obodo Ghana" },
            { "gip", "Ego Pound obodo Gibraltar" },
            { "gmd", "Ego Dalasi obodo Gambia" },
            { "gnf", "Ego Franc obodo Guinea" },
            { "gtq", "Ego Quetzal obodo Guatemala" },
            { "gyd", "Ego Dollar obodo Guyana" },
            { "hkd", "Ego Dollar Obodo Honk Kong" },
            { "hnl", "Ego Lempira obodo Honduras" },
            { "hrk", "Ego Kuna obodo Croatia" },
            { "htg", "Ego Gourde obodo Haiti" },
            { "huf", "Ego Forint obodo Hungary" },
            { "idr", "Ego Rupiah Obodo Indonesia" },
            { "ils", "Ego Shekel \u1ecdh\u1ee5r\u1ee5 obodo Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Ego Dinar obodo Iraq" },
            { "irr", "Ego Rial obodo Iran" },
            { "isk", "Ego Kr\u00f3na obodo Iceland" },
            { "jmd", "Ego Dollar obodo Jamaica" },
            { "jod", "Ego Dinar Obodo Jordan" },
            { "jpy", "Yen Japan" },
            { "kes", "Ego Shilling obodo Kenya" },
            { "kgs", "Ego Som Obodo Kyrgyzstan" },
            { "khr", "Ego Riel obodo Cambodia" },
            { "kmf", "Ego Franc obodo Comoros" },
            { "kpw", "Ego Won Obodo North Korea" },
            { "krw", "Ego Won Obodo South Korea" },
            { "kwd", "Ego Dinar Obodo Kuwait" },
            { "kyd", "Ego Dollar obodo Cayman Islands" },
            { "kzt", "Ego Tenge obodo Kazakhstani" },
            { "lak", "Ego Kip Obodo Laos" },
            { "lbp", "Ego Pound obodo Lebanon" },
            { "lkr", "Ego Rupee obodo Sri Lanka" },
            { "lrd", "Ego Dollar obodo Liberia" },
            { "lsl", "This is not a translation" },
            { "lyd", "Ego Dinar obodo Libya" },
            { "mad", "Ego Dirham obodo Morocco" },
            { "mdl", "Ego Leu obodo Moldova" },
            { "mga", "Ego Ariary obodo Madagascar" },
            { "mkd", "Ego Denar Obodo Macedonia" },
            { "mmk", "Ego Kyat obodo Myanmar" },
            { "mnt", "Ego Turgik Obodo Mongolia" },
            { "mop", "Ego Pataca nd\u1ecb Obodo Macanese" },
            { "mru", "Ego Ouguiya Obodo Mauritania" },
            { "mur", "Ego Rupee obodo Mauritania" },
            { "mvr", "Ego Rufiyaa obodo Moldova" },
            { "mwk", "Ego Kwacha obodo Malawi" },
            { "mxn", "Ego Peso obodo Mexico" },
            { "myr", "Ego Ringgit obodo Malaysia" },
            { "mzn", "Ego Metical obodo Mozambique" },
            { "nad", "Ego Dollar obodo Namibia" },
            { "ngn", "Na\u1ecbra" },
            { "nio", "Ego C\u00f3rodoba obodo Nicaragua" },
            { "nok", "Ego Krone Obodo Norway" },
            { "npr", "Ego Rupee obodo Nepal" },
            { "nzd", "Ego Dollar obodo New Zealand" },
            { "omr", "Ego Rial obodo Oman" },
            { "pab", "Ego Balboa obodo Panama" },
            { "pen", "Ego Sol obodo Peru" },
            { "pgk", "Ego Kina obodo Papua New Guinea" },
            { "php", "Ego piso obodo Philippine" },
            { "pkr", "Ego Rupee obodo Pakistan" },
            { "pln", "Ego Zloty mba Poland" },
            { "pyg", "Ego Guarani obodo Paraguay" },
            { "qar", "Ego Rial obodo Qatar" },
            { "ron", "Ego Leu obodo Romania" },
            { "rsd", "Ego Dinar obodo Serbia" },
            { "rub", "Ruble Russia" },
            { "rwf", "Ego Franc obodo Rwanda" },
            { "sar", "Ego Riyal obodo Saudi" },
            { "sbd", "Ego Dollar obodo Solomon Islands" },
            { "scr", "Ego Rupee obodo Seychelles" },
            { "sdg", "Ego Pound obodo Sudan" },
            { "sek", "Ego Krona Obodo Sweden" },
            { "sgd", "Ego Dollar obodo Singapore" },
            { "shp", "Ego Pound obodo St Helena" },
            { "sll", "Ego Leone obodo Sierra Leone" },
            { "sos", "Ego shilling obodo Somali" },
            { "srd", "Dollar Surinamese" },
            { "ssp", "Ego Pound obodo South Sudan" },
            { "stn", "Ego Dobra nke obodo S\u0101o Tom\u00e9 na Principe" },
            { "syp", "Ego Pound obodo Syria" },
            { "szl", "Ego Lilangeni obodo Swaziland" },
            { "thb", "Ego Baht obodo Thai" },
            { "tjs", "Who Somoni obodo Tajikistan" },
            { "tmt", "Ego Manat Obodo Turkmenistan" },
            { "tnd", "Ego Dinar Obodo Tunisia" },
            { "top", "Ego pa\u02bbanga obodo Tonga" },
            { "try", "Ego Lira obodo Turkey" },
            { "ttd", "Dollar Trinidad & Tobago" },
            { "twd", "Dollar obodo New Taiwan" },
            { "tzs", "Ego Shilling Obodo Tanzania" },
            { "uah", "Ego Hryvnia obodo Ukraine" },
            { "ugx", "Ego Shilling obodo Uganda" },
            { "usd", "Dollar US" },
            { "uyu", "Ego Peso obodo Uruguay" },
            { "uzs", "Ego Som obodo Uzbekistan" },
            { "ves", "Ego Bolivar obodo Venezuela" },
            { "vnd", "Ego Dong obodo Vietnam" },
            { "vuv", "Ego Vatu obodo Vanuatu" },
            { "wst", "Ego Tala obodo Samoa" },
            { "xaf", "Ego Franc mba etiti Africa" },
            { "xcd", "Ego Dollar obodo East Carribbean" },
            { "xof", "Ego CFA Franc obodo West Africa" },
            { "xpf", "Ego Franc obodo CFP" },
            { "xxx", "Ego Amagh\u1ecb" },
            { "yer", "Ego Rial obodo Yemeni" },
            { "zar", "Ego Rand obodo South Africa" },
            { "zmw", "Ego Kwacha Obodo Zambia" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ig.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ig extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "JPY", "\u00a5" },
            { "NGN", "\u20a6" },
            { "USD", "$" },
            { "aed", "Ego Dirham obodo United Arab Emirates" },
            { "afn", "Ego Afghani Obodo Afghanistan" },
            { "all", "Ego Lek Obodo Albania" },
            { "amd", "Ego Dram obodo Armenia" },
            { "ang", "Ego Antillean Guilder obodo Netherlands" },
            { "aoa", "Ego Kwanza obodo Angola" },
            { "ars", "Ego Peso obodo Argentina" },
            { "aud", "Ego Dollar obodo Australia" },
            { "awg", "Ego Florin obodo Aruba" },
            { "azn", "Ego Manat obodo Azerbaijan" },
            { "bam", "Akara mgbanwe ego obodo Bosnia-Herzegovina" },
            { "bbd", "Ego Dollar obodo Barbados" },
            { "bdt", "Ego Taka obodo Bangladesh" },
            { "bgn", "Ego Lev mba Bulgaria" },
            { "bhd", "Ego Dinar Obodo Bahrain" },
            { "bif", "Ego Franc obodo Burundi" },
            { "bmd", "Dollar Bermuda" },
            { "bnd", "Ego Dollar obodo Brunei" },
            { "bob", "Ego Boliviano obodo Bolivia" },
            { "brl", "Real Brazil" },
            { "bsd", "Ego Dollar Obodo Bahamas" },
            { "btn", "Ego Ngultrum obodo Bhutan" },
            { "bwp", "Ego Pula obodo Bostwana" },
            { "byn", "Ego Ruble mba Belarus" },
            { "bzd", "Dollar Belize" },
            { "cad", "Dollar Canada" },
            { "cdf", "Ego Franc obodo Congo" },
            { "chf", "Ego Franc mba Switzerland" },
            { "clp", "Ego Peso obodo Chile" },
            { "cnh", "Ego Yuan Obodo China (nd\u1ecb bi na mmiri)" },
            { "cny", "Yuan China" },
            { "cop", "Ego Peso obodo Columbia" },
            { "crc", "Ego Col\u00f3n obodo Costa Rica" },
            { "cuc", "Ego Peso e nwere ike \u1ecbgbanwe nke obodo Cuba" },
            { "cup", "Ego Peso obodo Cuba" },
            { "cve", "Escudo Caboverdiano" },
            { "czk", "Ego Koruna obodo Czech" },
            { "djf", "Ego Franc obodo Djibouti" },
            { "dkk", "Ego Krone Obodo Denmark" },
            { "dop", "Ego Peso Obodo Dominica" },
            { "dzd", "Ego Dinar Obodo Algeria" },
            { "egp", "Ego Pound obodo Egypt" },
            { "ern", "Ego Nakfa obodo Eritrea" },
            { "etb", "Ego Birr obodo Ethiopia" },
            { "eur", "Euro" },
            { "fjd", "Ego Dollar obodo Fiji" },
            { "fkp", "Ego Pound obodo Falkland Islands" },
            { "gbp", "Pound British" },
            { "gel", "Ego Lari Obodo Georgia" },
            { "ghs", "Ego Cedi obodo Ghana" },
            { "gip", "Ego Pound obodo Gibraltar" },
            { "gmd", "Ego Dalasi obodo Gambia" },
            { "gnf", "Ego Franc obodo Guinea" },
            { "gtq", "Ego Quetzal obodo Guatemala" },
            { "gyd", "Ego Dollar obodo Guyana" },
            { "hkd", "Ego Dollar Obodo Honk Kong" },
            { "hnl", "Ego Lempira obodo Honduras" },
            { "hrk", "Ego Kuna obodo Croatia" },
            { "htg", "Ego Gourde obodo Haiti" },
            { "huf", "Ego Forint obodo Hungary" },
            { "idr", "Ego Rupiah Obodo Indonesia" },
            { "ils", "Ego Shekel \u1ecdh\u1ee5r\u1ee5 obodo Israel" },
            { "inr", "Rupee India" },
            { "iqd", "Ego Dinar obodo Iraq" },
            { "irr", "Ego Rial obodo Iran" },
            { "isk", "Ego Kr\u00f3na obodo Iceland" },
            { "jmd", "Ego Dollar obodo Jamaica" },
            { "jod", "Ego Dinar Obodo Jordan" },
            { "jpy", "Yen Japan" },
            { "kes", "Ego Shilling obodo Kenya" },
            { "kgs", "Ego Som Obodo Kyrgyzstan" },
            { "khr", "Ego Riel obodo Cambodia" },
            { "kmf", "Ego Franc obodo Comoros" },
            { "kpw", "Ego Won Obodo North Korea" },
            { "krw", "Ego Won Obodo South Korea" },
            { "kwd", "Ego Dinar Obodo Kuwait" },
            { "kyd", "Ego Dollar obodo Cayman Islands" },
            { "kzt", "Ego Tenge obodo Kazakhstani" },
            { "lak", "Ego Kip Obodo Laos" },
            { "lbp", "Ego Pound obodo Lebanon" },
            { "lkr", "Ego Rupee obodo Sri Lanka" },
            { "lrd", "Ego Dollar obodo Liberia" },
            { "lsl", "Ego loti obodo Lesotho" },
            { "lyd", "Ego Dinar obodo Libya" },
            { "mad", "Ego Dirham obodo Morocco" },
            { "mdl", "Ego Leu obodo Moldova" },
            { "mga", "Ego Ariary obodo Madagascar" },
            { "mkd", "Ego Denar Obodo Macedonia" },
            { "mmk", "Ego Kyat obodo Myanmar" },
            { "mnt", "Ego Turgik Obodo Mongolia" },
            { "mop", "Ego Pataca nd\u1ecb Obodo Macanese" },
            { "mru", "Ego Ouguiya Obodo Mauritania" },
            { "mur", "Ego Rupee obodo Mauritania" },
            { "mvr", "Ego Rufiyaa obodo Moldova" },
            { "mwk", "Ego Kwacha obodo Malawi" },
            { "mxn", "Ego Peso obodo Mexico" },
            { "myr", "Ego Ringgit obodo Malaysia" },
            { "mzn", "Ego Metical obodo Mozambique" },
            { "nad", "Ego Dollar obodo Namibia" },
            { "ngn", "Na\u1ecbra" },
            { "nio", "Ego C\u00f3rodoba obodo Nicaragua" },
            { "nok", "Ego Krone Obodo Norway" },
            { "npr", "Ego Rupee obodo Nepal" },
            { "nzd", "Ego Dollar obodo New Zealand" },
            { "omr", "Ego Rial obodo Oman" },
            { "pab", "Ego Balboa obodo Panama" },
            { "pen", "Ego Sol obodo Peru" },
            { "pgk", "Ego Kina obodo Papua New Guinea" },
            { "php", "Ego piso obodo Philippine" },
            { "pkr", "Ego Rupee obodo Pakistan" },
            { "pln", "Ego Zloty mba Poland" },
            { "pyg", "Ego Guarani obodo Paraguay" },
            { "qar", "Ego Rial obodo Qatar" },
            { "ron", "Ego Leu obodo Romania" },
            { "rsd", "Ego Dinar obodo Serbia" },
            { "rub", "Ruble Russia" },
            { "rwf", "Ego Franc obodo Rwanda" },
            { "sar", "Ego Riyal obodo Saudi" },
            { "sbd", "Ego Dollar obodo Solomon Islands" },
            { "scr", "Ego Rupee obodo Seychelles" },
            { "sdg", "Ego Pound obodo Sudan" },
            { "sek", "Ego Krona Obodo Sweden" },
            { "sgd", "Ego Dollar obodo Singapore" },
            { "shp", "Ego Pound obodo St Helena" },
            { "sle", "Ego Leone obodo Sierra Leone" },
            { "sll", "Ego Leone obodo Sierra Leone (1964\u20142022)" },
            { "sos", "Ego shilling obodo Somali" },
            { "srd", "Dollar Surinamese" },
            { "ssp", "Ego Pound obodo South Sudan" },
            { "stn", "Ego Dobra nke obodo S\u0101o Tom\u00e9 na Principe" },
            { "syp", "Ego Pound obodo Syria" },
            { "szl", "Ego Lilangeni obodo Swaziland" },
            { "thb", "Ego Baht obodo Thai" },
            { "tjs", "Who Somoni obodo Tajikistan" },
            { "tmt", "Ego Manat Obodo Turkmenistan" },
            { "tnd", "Ego Dinar Obodo Tunisia" },
            { "top", "Ego pa\u02bbanga obodo Tonga" },
            { "try", "Ego Lira obodo Turkey" },
            { "ttd", "Dollar Trinidad & Tobago" },
            { "twd", "Dollar obodo New Taiwan" },
            { "tzs", "Ego Shilling Obodo Tanzania" },
            { "uah", "Ego Hryvnia obodo Ukraine" },
            { "ugx", "Ego Shilling obodo Uganda" },
            { "usd", "Dollar US" },
            { "uyu", "Ego Peso obodo Uruguay" },
            { "uzs", "Ego Som obodo Uzbekistan" },
            { "ves", "Ego Bolivar obodo Venezuela" },
            { "vnd", "Ego Dong obodo Vietnam" },
            { "vuv", "Ego Vatu obodo Vanuatu" },
            { "wst", "Ego Tala obodo Samoa" },
            { "xaf", "Ego Franc mba etiti Africa" },
            { "xcd", "Ego Dollar obodo East Carribbean" },
            { "xof", "Ego CFA Franc obodo West Africa" },
            { "xpf", "Ego Franc obodo CFP" },
            { "xxx", "Ego Amagh\u1ecb" },
            { "yer", "Ego Rial obodo Yemeni" },
            { "zar", "Ego Rand obodo South Africa" },
            { "zmw", "Ego Kwacha Obodo Zambia" },
        };
        return data;
    }
}
